@@ -1,9 +1,11 @@
 name = "labelbox"
-__version__ = "2.6.0"
+__version__ = "3.3.0"
 
-from labelbox.client import Client
-from labelbox.schema.bulk_import_request import BulkImportRequest
 from labelbox.schema.project import Project
+from labelbox.client import Client
+from labelbox.schema.model import Model
+from labelbox.schema.bulk_import_request import BulkImportRequest
+from labelbox.schema.annotation_import import MALPredictionImport, MEAPredictionImport
 from labelbox.schema.dataset import Dataset
 from labelbox.schema.data_row import DataRow
 from labelbox.schema.label import Label
@@ -12,9 +14,10 @@ from labelbox.schema.user import User
 from labelbox.schema.organization import Organization
 from labelbox.schema.task import Task
 from labelbox.schema.labeling_frontend import LabelingFrontend
-from labelbox.schema.asset_metadata import AssetMetadata
+from labelbox.schema.asset_attachment import AssetAttachment
 from labelbox.schema.webhook import Webhook
-from labelbox.schema.prediction import Prediction, PredictionModel
-from labelbox.schema.ontology import Ontology
+from labelbox.schema.ontology import Ontology, OntologyBuilder, Classification, Option, Tool
 from labelbox.schema.role import Role, ProjectRole
 from labelbox.schema.invite import Invite, InviteLimit
+from labelbox.schema.data_row_metadata import DataRowMetadataOntology
+from labelbox.schema.model_run import ModelRun
