@@ -10,7 +10,6 @@ import backoff
 import ndjson
 import requests
 from pydantic import BaseModel, validator
-from requests.api import request
 from typing_extensions import Literal
 from typing import (Any, List, Optional, BinaryIO, Dict, Iterable, Tuple, Union,
                     Type, Set)
@@ -193,7 +192,7 @@ class BulkImportRequest(DbObject):
         res = res[utils.camel_case(BulkImportRequest.type_name())]
         self._set_field_values(res)
 
-    def wait_until_done(self, sleep_time_seconds: int = 30) -> None:
+    def wait_until_done(self, sleep_time_seconds: int = 5) -> None:
         """Blocks import job until certain conditions are met.
 
         Blocks until the BulkImportRequest.state changes either to
@@ -387,6 +386,21 @@ class BulkImportRequest(DbObject):
                                                       file_name, file_data)
         return cls(client, response_data["createBulkImportRequest"])
 
+    def delete(self) -> None:
+        """ Deletes the import job and also any annotations created by this import.
+
+        Returns:
+            None
+        """
+        id_param = "bulk_request_id"
+        query_str = """mutation deleteBulkImportRequestPyApi($%s: ID!) {
+            deleteBulkImportRequest(where: {id: $%s}) {
+                id
+                name
+            }
+        }""" % (id_param, id_param)
+        self.client.execute(query_str, {id_param: self.uid})
+
 
 def _validate_ndjson(lines: Iterable[Dict[str, Any]],
                      project: "labelbox.Project") -> None:
