@@ -24,6 +24,11 @@ except AttributeError:
     from backports.datetime_fromisoformat import MonkeyPatch
     MonkeyPatch.patch_fromisoformat()
 
+try:
+    from labelbox.data.serialization import LBV1Converter
+except ImportError:
+    pass
+
 logger = logging.getLogger(__name__)
 
 
@@ -50,8 +55,6 @@ class Project(DbObject, Updateable, Deletable):
         labeling_parameter_overrides (Relationship): `ToMany` relationship to LabelingParameterOverride
         webhooks (Relationship): `ToMany` relationship to Webhook
         benchmarks (Relationship): `ToMany` relationship to Benchmark
-        active_prediction_model (Relationship): `ToOne` relationship to PredictionModel
-        predictions (Relationship): `ToMany` relationship to Prediction
         ontology (Relationship): `ToOne` relationship to Ontology
     """
     name = Field.String("name")
@@ -67,7 +70,6 @@ class Project(DbObject, Updateable, Deletable):
     datasets = Relationship.ToMany("Dataset", True)
     created_by = Relationship.ToOne("User", False, "created_by")
     organization = Relationship.ToOne("Organization", False)
-    reviews = Relationship.ToMany("Review", True)
     labeling_frontend = Relationship.ToOne("LabelingFrontend")
     labeling_frontend_options = Relationship.ToMany(
         "LabelingFrontendOptions", False, "labeling_frontend_options")
@@ -75,9 +77,6 @@ class Project(DbObject, Updateable, Deletable):
         "LabelingParameterOverride", False, "labeling_parameter_overrides")
     webhooks = Relationship.ToMany("Webhook", False)
     benchmarks = Relationship.ToMany("Benchmark", False)
-    active_prediction_model = Relationship.ToOne("PredictionModel", False,
-                                                 "active_prediction_model")
-    predictions = Relationship.ToMany("Prediction", False)
     ontology = Relationship.ToOne("Ontology", True)
 
     def members(self):
@@ -96,38 +95,6 @@ class Project(DbObject, Updateable, Deletable):
                                    {id_param: str(self.uid)},
                                    ["project", "members"], ProjectMember)
 
-    def create_label(self, **kwargs):
-        """ Creates a label on a Legacy Editor project. Not supported in the new Editor.
-        Args:
-            **kwargs: Label attributes. At minimum, the label `DataRow`.
-        """
-        # Copy-paste of Client._create code so we can inject
-        # a connection to Type. Type objects are on their way to being
-        # deprecated and we don't want the Py client lib user to know
-        # about them. At the same time they're connected to a Label at
-        # label creation in a non-standard way (connect via name).
-        logger.warning(
-            "`create_label` is deprecated and is not compatible with the new editor."
-        )
-
-        Label = Entity.Label
-
-        kwargs[Label.project] = self
-        kwargs[Label.seconds_to_label] = kwargs.get(Label.seconds_to_label.name,
-                                                    0.0)
-        data = {
-            Label.attribute(attr) if isinstance(attr, str) else attr:
-            value.uid if isinstance(value, DbObject) else value
-            for attr, value in kwargs.items()
-        }
-
-        query_str, params = query.create(Label, data)
-        # Inject connection to Type
-        query_str = query_str.replace(
-            "data: {", "data: {type: {connect: {name: \"Any\"}} ")
-        res = self.client.execute(query_str, params)
-        return Label(self.client, res["createLabel"])
-
     def labels(self, datasets=None, order_by=None):
         """ Custom relationship expansion method to support limited filtering.
 
@@ -199,7 +166,55 @@ class Project(DbObject, Updateable, Deletable):
                 self.uid)
             time.sleep(sleep_time)
 
-    def export_labels(self, timeout_seconds=60):
+    def video_label_generator(self, timeout_seconds=600):
+        """
+        Download video annotations
+
+        Returns:
+            LabelGenerator for accessing labels for each video
+        """
+        _check_converter_import()
+        json_data = self.export_labels(download=True,
+                                       timeout_seconds=timeout_seconds)
+        if json_data is None:
+            raise TimeoutError(
+                f"Unable to download labels in {timeout_seconds} seconds."
+                "Please try again or contact support if the issue persists.")
+        is_video = [
+            'frames' in row['Label'] for row in json_data if row['Label']
+        ]
+        if len(is_video) and not all(is_video):
+            raise ValueError(
+                "Found non-video data rows in export. "
+                "Use project.export_labels() to export projects with mixed data types. "
+                "Or use project.label_generator() for text and imagery data.")
+        return LBV1Converter.deserialize_video(json_data, self.client)
+
+    def label_generator(self, timeout_seconds=600):
+        """
+        Download text and image annotations
+
+        Returns:
+            LabelGenerator for accessing labels for each text or image
+        """
+        _check_converter_import()
+        json_data = self.export_labels(download=True,
+                                       timeout_seconds=timeout_seconds)
+        if json_data is None:
+            raise TimeoutError(
+                f"Unable to download labels in {timeout_seconds} seconds."
+                "Please try again or contact support if the issue persists.")
+        is_video = [
+            'frames' in row['Label'] for row in json_data if row['Label']
+        ]
+        if len(is_video) and any(is_video):
+            raise ValueError(
+                "Found video data rows in export. "
+                "Use project.export_labels() to export projects with mixed data types. "
+                "Or use project.video_label_generator() for video data.")
+        return LBV1Converter.deserialize(json_data)
+
+    def export_labels(self, download=False, timeout_seconds=600):
         """ Calls the server-side Label exporting that generates a JSON
         payload, and returns the URL to that payload.
 
@@ -221,7 +236,13 @@ class Project(DbObject, Updateable, Deletable):
             res = self.client.execute(query_str, {id_param: self.uid})
             res = res["exportLabels"]
             if not res["shouldPoll"]:
-                return res["downloadUrl"]
+                url = res['downloadUrl']
+                if not download:
+                    return url
+                else:
+                    response = requests.get(url)
+                    response.raise_for_status()
+                    return response.json()
 
             timeout_seconds -= sleep_time
             if timeout_seconds <= 0:
@@ -397,8 +418,7 @@ class Project(DbObject, Updateable, Deletable):
             LFO, {
                 LFO.project: self,
                 LFO.labeling_frontend: labeling_frontend,
-                LFO.customization_options: labeling_frontend_options,
-                LFO.organization: organization
+                LFO.customization_options: labeling_frontend_options
             })
 
         timestamp = datetime.now(timezone.utc).strftime("%Y-%m-%dT%H:%M:%SZ")
@@ -537,77 +557,6 @@ class Project(DbObject, Updateable, Deletable):
         res = self.client.execute(query_str, {id_param: self.uid})
         return res["extendReservations"]
 
-    def create_prediction_model(self, name, version):
-        """ Creates a PredictionModel connected to a Legacy Editor Project.
-
-        Args:
-            name (str): The new PredictionModel's name.
-            version (int): The new PredictionModel's version.
-        Returns:
-            A newly created PredictionModel.
-        """
-
-        logger.warning(
-            "`create_prediction_model` is deprecated and is not compatible with the new editor."
-        )
-
-        PM = Entity.PredictionModel
-        model = self.client._create(PM, {
-            PM.name.name: name,
-            PM.version.name: version
-        })
-        self.active_prediction_model.connect(model)
-        return model
-
-    def create_prediction(self, label, data_row, prediction_model=None):
-        """ Creates a Prediction within a Legacy Editor Project. Not supported
-        in the new Editor.
-
-        Args:
-            label (str): The `label` field of the new Prediction.
-            data_row (DataRow): The DataRow for which the Prediction is created.
-            prediction_model (PredictionModel or None): The PredictionModel
-                within which the new Prediction is created. If None then this
-                Project's active_prediction_model is used.
-        Return:
-            A newly created Prediction.
-        Raises:
-            labelbox.excepions.InvalidQueryError: if given `prediction_model`
-                is None and this Project's active_prediction_model is also
-                None.
-        """
-        logger.warning(
-            "`create_prediction` is deprecated and is not compatible with the new editor."
-        )
-
-        if prediction_model is None:
-            prediction_model = self.active_prediction_model()
-            if prediction_model is None:
-                raise InvalidQueryError(
-                    "Project '%s' has no active prediction model" % self.name)
-
-        label_param = "label"
-        model_param = "prediction_model_id"
-        project_param = "project_id"
-        data_row_param = "data_row_id"
-
-        Prediction = Entity.Prediction
-        query_str = """mutation CreatePredictionPyApi(
-            $%s: String!, $%s: ID!, $%s: ID!, $%s: ID!) {createPrediction(
-            data: {label: $%s, predictionModelId: $%s, projectId: $%s,
-                   dataRowId: $%s})
-            {%s}}""" % (label_param, model_param, project_param, data_row_param,
-                        label_param, model_param, project_param, data_row_param,
-                        query.results_query_part(Prediction))
-        params = {
-            label_param: label,
-            model_param: prediction_model.uid,
-            data_row_param: data_row.uid,
-            project_param: self.uid
-        }
-        res = self.client.execute(query_str, params)
-        return Prediction(self.client, res["createPrediction"])
-
     def enable_model_assisted_labeling(self, toggle: bool = True) -> bool:
         """ Turns model assisted labeling either on or off based on input
 
@@ -633,6 +582,26 @@ class Project(DbObject, Updateable, Deletable):
         return res["project"]["showPredictionsToLabelers"][
             "showingPredictionsToLabelers"]
 
+    def bulk_import_requests(self):
+        """ Returns bulk import request objects which are used in model-assisted labeling.
+        These are returned with the oldest first, and most recent last.
+        """
+
+        id_param = "project_id"
+        query_str = """query ListAllImportRequestsPyApi($%s: ID!) {
+            bulkImportRequests (
+                where: { projectId: $%s }
+                skip: %%d
+                first: %%d
+            ) {
+                %s
+            }
+        }""" % (id_param, id_param,
+                query.results_query_part(Entity.BulkImportRequest))
+        return PaginatedCollection(self.client, query_str,
+                                   {id_param: str(self.uid)},
+                                   ["bulkImportRequests"], BulkImportRequest)
+
     def upload_annotations(
             self,
             name: str,
@@ -723,3 +692,11 @@ LabelerPerformance = namedtuple(
     "consensus average_benchmark_agreement last_activity_time")
 LabelerPerformance.__doc__ = (
     "Named tuple containing info about a labeler's performance.")
+
+
+def _check_converter_import():
+    if 'LBV1Converter' not in globals():
+        raise ImportError(
+            "Missing dependencies to import converter. "
+            "Use `pip install labelbox[data]` to add missing dependencies. "
+            "or download raw json with project.export_labels()")
